@@ -20,7 +20,7 @@
 
 import json
 import re
-from typing import Dict
+from typing import Dict, Optional
 
 from ruamel.yaml import YAML
 from ruamel.yaml.error import YAMLError, YAMLFutureWarning
@@ -39,7 +39,7 @@ class GettextDiscovery(BaseDiscovery):
     mask = "*.po"
     new_base_mask = "*.pot"
 
-    def discover(self, eager: bool = False):
+    def discover(self, eager: bool = False, hint: Optional[str] = None):
         for result in super().discover(eager=eager):
             if "template" not in result:
                 yield result
@@ -81,7 +81,25 @@ class XliffDiscovery(BaseDiscovery):
     """XLIFF files discovery."""
 
     file_format = "xliff"
-    mask = ("*.xliff", "*.xlf", "*.sdlxliff", "*.mxliff")
+    mask = ("*.xliff", "*.xlf", "*.sdlxliff", "*.mxliff", "*.poxliff")
+
+    def adjust_format(self, result: Dict[str, str]):
+        if "template" in result:
+            base = result["template"]
+        else:
+            base = result["filemask"]
+
+        path = list(self.finder.mask_matches(base))[0]
+
+        if not hasattr(path, "open"):
+            return
+
+        with self.finder.open(path, "r") as handle:
+            content = handle.read()
+            if 'restype="x-gettext' in content:
+                result["file_format"] = "poxliff"
+            elif "<x " not in content and "<g " not in content:
+                result["file_format"] = "plainxliff"
 
 
 @register_discovery
@@ -114,7 +132,7 @@ class AndroidDiscovery(BaseDiscovery):
 
     file_format = "aresource"
 
-    def get_masks(self, eager: bool = False):
+    def get_masks(self, eager: bool = False, hint: Optional[str] = None):
         """Return all file masks found in the directory.
 
         It is expected to contain duplicates."""
@@ -134,7 +152,7 @@ class OSXDiscovery(EncodingDiscovery):
         "utf-16": "strings-utf16",
     }
 
-    def get_masks(self, eager: bool = False):
+    def get_masks(self, eager: bool = False, hint: Optional[str] = None):
         """Return all file masks found in the directory.
 
         It is expected to contain duplicates."""
@@ -157,7 +175,7 @@ class StringsdictDiscovery(BaseDiscovery):
 
     file_format = "stringsdict"
 
-    def get_masks(self, eager: bool = False):
+    def get_masks(self, eager: bool = False, hint: Optional[str] = None):
         """Return all file masks found in the directory.
 
         It is expected to contain duplicates."""
@@ -197,7 +215,7 @@ class RESXDiscovery(BaseDiscovery):
         yield mask.replace(".*", "")
         yield from super().possible_templates(language, mask)
 
-    def get_masks(self, eager: bool = False):
+    def get_masks(self, eager: bool = False, hint: Optional[str] = None):
         """Return all file masks found in the directory.
 
         It is expected to contain duplicates."""
@@ -208,7 +226,7 @@ class RESXDiscovery(BaseDiscovery):
                 continue
             mask[-1] = f"{base}.*.{ext}"
             yield {"filemask": "/".join(mask)}
-        yield from super().get_masks(eager=eager)
+        yield from super().get_masks(eager=eager, hint=hint)
 
 
 @register_discovery
@@ -423,6 +441,14 @@ class HTMLDiscovery(MonoTemplateDiscovery):
     mask = ("*.html", "*.htm")
 
 
+@register_discovery
+class TXTDiscovery(MonoTemplateDiscovery):
+    """TXT files discovery."""
+
+    file_format = "txt"
+    mask = "*.txt"
+
+
 @register_discovery
 class ODFDiscovery(MonoTemplateDiscovery):
     """ODF files discovery."""
